==> igniteui-webcomponents-core-3.2.4.tgz: package/esm5/lib/WebCardDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebCardDescription } from "./WebCardDescription";
/**
 * @hidden
 */
var WebCardDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebCardDescriptionMetadata, _super);
    function WebCardDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebCardDescriptionMetadata.b = function (a) {
        if (WebCardDescriptionMetadata.a == null) {
            WebCardDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebCardDescriptionMetadata.c(WebCardDescriptionMetadata.a);
        }
        if (a.g(WebCardDescriptionMetadata.a)) {
            return;
        }
        a.s(WebCardDescriptionMetadata.a);
    };
    WebCardDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:Card");
        a.item("Elevated", "Boolean");
    };
    WebCardDescriptionMetadata.d = function (a) {
        WebCardDescriptionMetadata.b(a);
        a.u("WebCard", function () { return new WebCardDescription(); });
        a.t("WebCard", WebCardDescriptionMetadata.a);
    };
    WebCardDescriptionMetadata.$t = markType(WebCardDescriptionMetadata, 'WebCardDescriptionMetadata');
    WebCardDescriptionMetadata.a = null;
    return WebCardDescriptionMetadata;
}(Base));
export { WebCardDescriptionMetadata };

==> igniteui-webcomponents-core-4.0.2.tgz: package/esm5/lib/WebCardDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebCardDescription } from "./WebCardDescription";
/**
 * @hidden
 */
var WebCardDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebCardDescriptionMetadata, _super);
    function WebCardDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebCardDescriptionMetadata.b = function (a) {
        if (WebCardDescriptionMetadata.a == null) {
            WebCardDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebCardDescriptionMetadata.c(WebCardDescriptionMetadata.a);
        }
        if (a.j(WebCardDescriptionMetadata.a)) {
            return;
        }
        a.y(WebCardDescriptionMetadata.a);
    };
    WebCardDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:Card");
        a.item("__tagNameWC", "String:igc-card");
        a.item("Elevated", "Boolean");
    };
    WebCardDescriptionMetadata.d = function (a) {
        WebCardDescriptionMetadata.b(a);
        a.aa("WebCard", function () { return new WebCardDescription(); });
        a.z("WebCard", WebCardDescriptionMetadata.a);
    };
    WebCardDescriptionMetadata.$t = markType(WebCardDescriptionMetadata, 'WebCardDescriptionMetadata');
    WebCardDescriptionMetadata.a = null;
    return WebCardDescriptionMetadata;
}(Base));
export { WebCardDescriptionMetadata };
